% Figure script: Change in mean transfers are plotted with their distributions.

clear all; close all;

% read in output of sorting script: Mean_Transfer
TR = csvread('Trust_Risk_RT.csv', 1, 0);

T_pVnp = TR(:,6);
R_pVnp = TR(:,7);

Trust_M = mean(T_pVnp)
Trust_SEM = std(T_pVnp) / sqrt(length(T_pVnp))

Risk_M = mean(R_pVnp)
Risk_SEM = std(R_pVnp) / sqrt(length(R_pVnp))


figure()

  % ******************************
    %%% ADD HORIZONTAL LINES AT Y=0 *
    % ******************************
    
    plot([0.5 1.5],[0 0],  'k-', 'LineWidth', 1.5)
    

    x1 = 1;
    % adjustments (shifts) to plot errorbars in the right spot
    shift_1 = 0.25;     % errorbars from X coordinate
    shift_2 = 0.125;     % shifts dots to right of X2
    shift_3 = 0.125;     % shifts dots to right of X1
    left_s = -0.02;     % dot grouping shift
    right_s = 0.02;     % dot grouping shift
    
MS = 5;
fsize = 23;

% **********
% SET UP X and Y axes
% **********

min_max = [T_pVnp; R_pVnp];
y_min = min(min_max) - 0.5;
y_max = max(min_max) + 0.5;

% **********
% DOT PLOT
% **********

%%% separate overlapping dots
[s_b1, I_b1] = sort(T_pVnp); % I is index of ordered values - use for b2
s_b1ss = [s_b1 I_b1];

[s_b2, I_b2] = sort(R_pVnp);
s_b2ss = [s_b2 I_b2];

%%% separate overlapping dots
s_b1 = sort(T_pVnp);
s_b2 = sort(R_pVnp);

left    = [1:3:41];
middle  = [2:3:41];
right   = [3:3:41];

s_b1_l = s_b1(left);
s_b1_m = s_b1(middle);
s_b1_r = s_b1(right);

s_b2_l = s_b2(left);
s_b2_m = s_b2(middle);
s_b2_r = s_b2(right);

hold on;

% ***********
% PLOT DOTS *
% ***********

s1l = plot(x1+shift_3+left_s, s_b1_l, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.9 0.5 0.5], 'MarkerSize', MS);
s1m = plot(x1+shift_3, s_b1_m, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.9 0.5 0.5], 'MarkerSize', MS);
s1r = plot(x1+shift_3+right_s, s_b1_r, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.9 0.5 0.5], 'MarkerSize', MS);

s2l = plot(x1-shift_2+left_s, s_b2_l, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.5 0.9 0.5], 'MarkerSize', MS);
s2m = plot(x1-shift_2, s_b2_m, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.5 0.9 0.5], 'MarkerSize', MS);
s2r = plot(x1-shift_2+right_s, s_b2_r, 'o', 'MarkerEdgeColor',[0.1 0.1 0.1], 'MarkerFaceColor',[0.5 0.9 0.5], 'MarkerSize', MS);


% **********
% ERRORBAR *
% **********

errorbar([x1-shift_1 x1+shift_1],[Trust_M Risk_M],[Trust_SEM Risk_SEM], '.k', 'LineWidth',1.5); %'MarkerSize',10,

%%% ADD HORIZONTAL LINES AT THE MEAN

se = 0.07;

plot([x1+shift_1-se x1+shift_1+se],[Risk_M Risk_M], '-', 'LineWidth', 5, 'Color', [0.7 0.2 0]);
plot([x1-shift_1-se x1-shift_1+se],[Trust_M Trust_M],'-', 'LineWidth', 5, 'Color', [0.2 0.7 0]);


%%% ADD FIGURE LABELS
%legend('Threat','No Threat','Location','South')

ylim([(y_min-0.01) (y_max+0.01)]);
xlim([0.6 1.4]);
ylabel({'\Delta Mean RT'; '(threat - no threat)'},'FontSize',fsize)
set(gca,'FontSize',fsize,'box','on','linewidth',1.5, ...
    'XTick',[0.75 1.25], ...
    'XTickLabel',{'Trust', 'NS Control'})


set(gcf, 'PaperPositionMode', 'auto')
% print -f1 -dtiffn -r600 MeanTransfersDIFF_dots

hold off;